from typing import Any, Dict, Sequence, TypeVar


Argv = Sequence[str]
DictStrAny = Dict[str, Any]
DictStrStr = Dict[str, str]
T = TypeVar("T")
